@@ -5,6 +5,7 @@ from marshmallow import (
     pre_load,
     ValidationError,
 )
+from ...utils.utils import pre_load_date_fields
 
 
 class CompanyFilingResourceSchema(Schema):
@@ -14,6 +15,8 @@ class CompanyFilingResourceSchema(Schema):
     company_sec_id = fields.Integer(allow_none=True)
     company_ous_id = fields.Integer(allow_none=True)
     file_id = fields.Integer(required=True)
+    date = fields.DateTime(allow_none=True)
+    title = fields.String(allow_none=True)
     type = fields.String(allow_none=True)
     orig_file_url = fields.String(allow_none=True)
     is_deleted = fields.Boolean(allow_none=True)
@@ -35,3 +38,13 @@ class CompanyFilingResourceSchema(Schema):
             if in_data['company_ous_id'] is not None:
                 result += 1
         return result
+
+    def convert_string_to_datetime(self, in_data):
+        date_fields = ['date']
+
+        in_data = pre_load_date_fields(
+            in_data,
+            date_fields,
+            date_format='%Y%m%dT%H%M%S',
+        )
+        return in_data
