@@ -4,6 +4,7 @@ from sqlalchemy import (
     String,
     DateTime,
     Boolean,
+    ForeignKey,
 )
 from datetime import datetime
 
@@ -24,6 +25,11 @@ class CompanyOUSModel(Base):
     is_activated = Column(Boolean, nullable=True)
     last_crawl_date = Column(DateTime, nullable=True)
     industry_type = Column(String(50), nullable=True)
+    company_sec_link = Column(
+        Integer,
+        ForeignKey('companies_sec.id'),
+        nullable=True,
+    )
     updated_at = Column(
         DateTime,
         nullable=False,
