@@ -20,7 +20,7 @@ class ConditionEpidemiologyMapModel(Base):
         ForeignKey('conditions.id'),
         nullable=False,
     )
-    epidemiology = Column(
+    epidemiology_id = Column(
         Integer,
         ForeignKey('condition_epidemiology.id'),
         nullable=False,
@@ -33,4 +33,4 @@ class ConditionEpidemiologyMapModel(Base):
         onupdate=lambda: datetime.utcnow(),
     )
 
-    __table_args__ = (UniqueConstraint("condition_id", "epidemiology"),)
+    __table_args__ = (UniqueConstraint("condition_id", "epidemiology_id"),)
