@@ -12,5 +12,7 @@ class ConditionNormResourceSchema(Schema):
     condition_id = fields.Integer(required=True)
     condition_norm_cui = fields.String(required=True)
     condition_norm_cui_name = fields.String(required=True)
+    condition_norm_cui_broader = fields.String(required=True)
+    condition_norm_cui_name_broader = fields.String(required=True)
     condition_norm_name = fields.String(required=True)
     updated_at = fields.DateTime()
