@@ -12,7 +12,7 @@ class LatestPipelineProductResourceSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     product_name = fields.String(validate=not_blank, required=True)
-    norm_cui = fields.String(validate=not_blank, required=True)
+    intervention_id = fields.Integer(required=True)
     news_id = fields.Integer()
     latest_catalyst_date = fields.DateTime()
     updated_at = fields.DateTime()
@@ -34,7 +34,7 @@ class LatestPipelinePatchSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     product_name = fields.String(validate=not_blank, required=True)
-    norm_cui = fields.String(validate=not_blank, required=True)
+    intervention_id = fields.Integer(required=True)
     news_id = fields.Integer()
     latest_catalyst_date = fields.DateTime()
     updated_at = fields.DateTime()
