@@ -5,6 +5,7 @@ from sqlalchemy import (
     Text,
     DateTime,
     UniqueConstraint,
+    ForeignKey,
 )
 from datetime import datetime
 
@@ -17,6 +18,11 @@ class PatentModel(Base):
     id = Column(Integer, primary_key=True)
     patent_number = Column(String(128), nullable=False, index=True)
     jurisdiction = Column(String(128), nullable=False)
+    patent_application_id = Column(
+        Integer,
+        ForeignKey('patent_applications.id'),
+        nullable=True,
+    )
     appl_id = Column(String(128))
     app_grp_art_number = Column(String(128))
     app_type = Column(String(128))
@@ -29,6 +35,8 @@ class PatentModel(Base):
     inventors = Column(String(256))
     title = Column(String(256))
     url = Column(String(500))
+    app_class = Column(String(20))
+    app_sub_class = Column(String(20))
     grant_date = Column(DateTime)
     submission_date = Column(DateTime)
     app_filing_date = Column(DateTime)
