@@ -15,7 +15,7 @@ class PubmedModel(Base):
     id = Column(Integer, primary_key=True)
     pubmed_id = Column(Integer, unique=True)
     doi = Column(String(128), nullable=True)
-    url_link = Column(String(255))
+    publication_type = Column(Text, nullable=True)
     date_created = Column(DateTime, nullable=True)
     date_completed = Column(DateTime, nullable=True)
     date_revised = Column(DateTime, nullable=True)
@@ -29,6 +29,7 @@ class PubmedModel(Base):
     author_list = Column(Text, nullable=True)
     keyword_list = Column(Text, nullable=True)
     chemical_list = Column(Text, nullable=True)
+    mesh_list = Column(Text, nullable=True)
     coi_statement = Column(Text, nullable=True)
     updated_at = Column(
         DateTime,
